@@ -4,14 +4,11 @@
 Models for storing data from Campaign Disclosure Statements (Form 461).
 """
 from .filing import Form461Filing, Form461FilingVersion
-from .part5 import (
-    Form461Part5Item,
-    Form461Part5ItemVersion
-)
+from .part5 import Form461Part5Item, Form461Part5ItemVersion
 
 __all__ = (
     "Form461Filing",
     "Form461FilingVersion",
     "Form461Part5Item",
-    "Form461Part5ItemVersion"
+    "Form461Part5ItemVersion",
 )
