@@ -4,18 +4,9 @@
 Abstract base models for Form 496 models.
 """
 from .filing import Form496Filing, Form496FilingVersion
-from .part1 import (
-    Form496Part1Item,
-    Form496Part1ItemVersion
-)
-from .part2 import (
-    Form496Part2Item,
-    Form496Part2ItemVersion
-)
-from .part3 import (
-    Form496Part3Item,
-    Form496Part3ItemVersion
-)
+from .part1 import Form496Part1Item, Form496Part1ItemVersion
+from .part2 import Form496Part2Item, Form496Part2ItemVersion
+from .part3 import Form496Part3Item, Form496Part3ItemVersion
 
 __all__ = (
     "Form496Filing",
@@ -25,5 +16,5 @@ __all__ = (
     "Form496Part2Item",
     "Form496Part2ItemVersion",
     "Form496Part3Item",
-    "Form496Part3ItemVersion"
+    "Form496Part3ItemVersion",
 )
