@@ -13,10 +13,13 @@ class CalAccessProcessedFlatfilesConfig(AppConfig):
     """
     Application configuration.
     """
-    name = 'calaccess_processed_flatfiles'
+
+    name = "calaccess_processed_flatfiles"
     verbose_name = "CAL-ACCESS processed data: Flat files"
+    default_auto_field = "django.db.models.AutoField"
+
     # Where SQL files are stored in this application
-    sql_directory_path = os.path.join(os.path.dirname(__file__), 'sql')
+    sql_directory_path = os.path.join(os.path.dirname(__file__), "sql")
 
     def get_flat_names_list(self):
         """
@@ -35,8 +38,11 @@ class CalAccessProcessedFlatfilesConfig(AppConfig):
         Returns a dictionary crosswalk between flatfile names and proxies.
         """
         from . import proxies
-        return collections.OrderedDict({
-            'Candidates': proxies.OCDFlatCandidacyProxy,
-            'BallotMeasures': proxies.OCDFlatBallotMeasureContestProxy,
-            'RecallMeasures': proxies.OCDFlatRetentionContestProxy
-        })
+
+        return collections.OrderedDict(
+            {
+                "Candidates": proxies.OCDFlatCandidacyProxy,
+                "BallotMeasures": proxies.OCDFlatBallotMeasureContestProxy,
+                "RecallMeasures": proxies.OCDFlatRetentionContestProxy,
+            }
+        )
